# Copyright (C) 2019 Chintalagiri Shashank
#
# This file is part of Tendril.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
Paths Configuration Options
===========================
"""


from tendril.utils.config import ConfigOption
from tendril.utils import log
logger = log.get_logger(__name__, log.DEFAULT)

depends = ['tendril.config.core']


config_elements_paths = [
    ConfigOption(
        'DOCSTORE_ROOT',
        "os.path.join(INSTANCE_ROOT, 'docstore')",
        "Folder for the docstore filesystem"
    ),
    ConfigOption(
        'REFDOC_ROOT',
        "os.path.join(INSTANCE_ROOT, 'refdocs')",
        "Folder for the refdocs filesystem"
    ),
    ConfigOption(
        'INSTANCE_CACHE',
        "os.path.join(INSTANCE_ROOT, 'cache')",
        "Folder within which the tendril instance should store it's cache(s)."
        "Make sure the the users running tendril (as well as the webserver, "
        "if the web frontend is being used) have write access to this folder."
    ),
    ConfigOption(
        'SHAREDCACHE_ROOT',
        "os.path.join(INSTANCE_CACHE, 'shared')",
        "Folder for the shared cache filesystem"
    ),
    ConfigOption(
        'AUDIT_PATH',
        "os.path.join(INSTANCE_ROOT, 'manual-audit')",
        "Folder where files generated for manual audit should be stored"
    ),
    ConfigOption(
        'SVN_ROOT',
        "os.path.join(INSTANCE_ROOT, 'projects')",
        "Common ancestor for all VCS checkout folders. While tendril will "
        "try to descend into this folder indefinitely, avoid using overly "
        "generic paths (like '/' or '~') to avoid surprises and preserve "
        "performance."
    ),
    ConfigOption(
        'PROJECTS_ROOT',
        "SVN_ROOT",
        "Common ancestor for all project folders. Use this if your projects"
        "are in a single sub-tree of your VCS_ROOT, for example. \nWhile "
        "tendril will try to descend into this folder indefinitely, avoid "
        "using overly generic paths (like '/' or '~') to avoid surprises "
        "and preserve performance."
    ),
]


def load(manager):
    logger.debug("Loading {0}".format(__name__))
    manager.load_elements(config_elements_paths,
                          doc="Tendril Resource Paths Configuration")



# Copyright (C) 2019 Chintalagiri Shashank
#
# This file is part of Tendril.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
Core Configuration Constants
============================
"""

import os
from tendril.utils.config import install_config
from tendril.utils import log
logger = log.get_logger(__name__, log.DEFAULT)

depends = []


def load(manager):
    logger.debug("Loading {0}".format(__name__))
    install_config(manager, os.environ.get('TENDRIL_INSTANCE_NAME', 'tendril'))



# Copyright (C) 2022 Chintalagiri Shashank
#
# This file is part of EBS API Server.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
Logging Configuration Options
=============================
"""


from tendril.utils.config import ConfigOption

import logging
logger = logging.getLogger(__name__)

depends = ['tendril.config.core']


config_elements_log = [
    ConfigOption(
        'LOG_LEVEL', "'INFO'",
        "The logging level to use.",
        parser=logging.getLevelName
    ),
    ConfigOption(
        'JSON_LOGS', "''",
        "Whether to use JSON logging. Applies only to the logfile, and not to the "
        "logs displayed on the console.",
        parser=bool
    ),
    ConfigOption(
        'LOG_PATH', "os.path.join('/var/log', 'tendril', '{}.log'.format(INSTANCE_NAME))",
        "Full path (including filename) to write logs to.",
    ),
    ConfigOption(
        'LOG_COMPACT_TS', 'True',
        "Whether to shorten the timestamp. See LOG_COMPACT_TS_READABLE.",
        parser=bool
    ),
    ConfigOption(
        'LOG_COMPACT_TS_READABLE', 'True',
        "Whether to use a readable format for the compact timestamp. Does not show year and "
        "uses minimal punctuation to keep it short yet readable. If False, shows UNIX "
        "timestamp only, which is even shorter.",
        parser=bool
    ),
    ConfigOption(
        'LOG_COMPACT_SOURCE', 'True',
        "Whether to shorten the source module name.",
        parser=bool
    ),
    ConfigOption(
        'LOG_COMPACT_SOURCE_MAXLEN', '18',
        "Target max length for the source module. Actual length might yet be longer.",
        parser=int
    ),
    ConfigOption(
        'LOG_COMPACT_LEVEL', 'True',
        "Whether to shorten the level name to one letter.",
        parser=bool
    ),
    ConfigOption(
        'LOG_COMPACT_LEVEL_ICON', 'False',
        "Whether to show the level icon instead of the level name. Use only for regular, full "
        "featured terminals. The single letter representation is usually better.",
        parser=bool
    ),
    ConfigOption(
        'LOG_INCLUDE_HOSTNAME', 'False',
        "Whether to include hostname in the log. This is provided to help deal with logs "
        "from multiple replicas or components running in a containerized environment.",
        parser=bool
    ),
    ConfigOption(
        'LOG_HOSTNAME_PREFIX', '""',
        "If set, this prefix is stripped from the hostname and only the remainder is "
        "included in the log message."
    )
]


def load(manager):
    logger.debug("Loading {0}".format(__name__))
    manager.load_elements(config_elements_log,
                          doc="Tendril Server Logging Configuration")
    from tendril.utils import log
    log.apply_config(manager)



# Copyright (C) 2019 Chintalagiri Shashank
#
# This file is part of Tendril.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
Core Metadata Configuration Options
===================================
"""


from tendril.utils.config import ConfigOption
from tendril.utils import log
logger = log.get_logger(__name__, log.DEFAULT)

depends = ['tendril.config.core']


config_elements_coremeta = [
    ConfigOption(
        'ADMIN_FULLNAME',
        "''",
        "Instance Administrator Name"
    ),
    ConfigOption(
        'ADMIN_EMAIL',
        "''",
        "Instance Administrator E-mail Address"
    ),
    ConfigOption(
        'INSTANCE_SOURCES',
        '"https://github.com/tendril-framework"',
        'The location of the sources of the tendril code used by the instance'
    ),
    ConfigOption(
        'INSTANCE_FOLDER_SOURCES',
        '"https://github.com/tendril-framework/tendril-instance-cookiecutter"',
        'The location of the sources of the tendril instance folder used by '
        'the instance'
    ),
    ConfigOption(
        'INSTANCE_DOCUMENTATION_PATH',
        '"http://tendril.chintal.in/doc"',
        "The location of the documentation related to the instance"
    ),
]


def load(manager):
    logger.debug("Loading {0}".format(__name__))
    manager.load_elements(config_elements_coremeta,
                          doc="Tendril Core Metadata Configuration")



# Copyright (C) 2019 Chintalagiri Shashank
#
# This file is part of Tendril.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
Mail Server Configuration Options
=================================
"""


from tendril.utils.config import ConfigOption
from tendril.utils import log
logger = log.get_logger(__name__, log.DEFAULT)

depends = ['tendril.config.core']


config_elements_mail = [
    ConfigOption(
        'MAIL_USERNAME',
        "None",
        "The username to authenticate with the SMTP server"
    ),
    ConfigOption(
        'MAIL_PASSWORD',
        "None",
        "The password to authenticate with the SMTP server"
    ),
    ConfigOption(
        'MAIL_DEFAULT_SENDER',
        "None",
        "The sender to use when sending emails"
    ),
    ConfigOption(
        'MAIL_SERVER',
        "None",
        "The host of the SMTP server to use"
    ),
    ConfigOption(
        'MAIL_PORT',
        "None",
        "The port of the SMTP server to use"
    ),
    ConfigOption(
        'MAIL_PORT',
        "587",
        "The port of the SMTP server to use"
    ),
    ConfigOption(
        'MAIL_USE_SSL',
        "True",
        "Whether to use SSL when sending emails"
    ),
    ConfigOption(
        'MAIL_USE_TLS',
        "False",
        "Whether to use TLS when sending emails"
    )
]


def load(manager):
    logger.debug("Loading {0}".format(__name__))
    manager.load_elements(config_elements_mail,
                          doc="Tendril E-mail Configuration")
